@@ -10,11 +10,11 @@ package Crypt::Random::Seed::Embedded;
 use strict;
 use warnings;
 use Fcntl;
-use Carp qw/carp croak/;
+use Carp qw/croak/;
 
 ## no critic (constant)
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 use constant UINT32_SIZE => 4;
 
 sub new {
@@ -190,9 +190,8 @@ package Math::Random::ISAAC::PP::Embedded;
 
 use strict;
 use warnings;
-use Carp ();
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 use constant {
     randrsl => 0, randcnt => 1, randmem => 2,
     randa   => 3, randb   => 4, randc   => 5,
@@ -228,9 +227,7 @@ sub _isaac {
     my $self = shift;
     use integer;
 
-    my $mm = $self->[randmem];
-    my $r  = $self->[randrsl];
-    my $aa = $self->[randa];
+    my($mm, $r, $aa) = @{$self}[randmem,randrsl,randa];
     my $bb = ($self->[randb] + (++$self->[randc])) & 0xffffffff;
     my ($x, $y); # temporary storage
 
@@ -269,8 +266,7 @@ sub _randinit {
     use integer;
 
     my ($c, $d, $e, $f, $g, $h, $j, $k) = (0x9e3779b9)x8; # The golden ratio.
-    my $mm = $self->[randmem];
-    my $r  = $self->[randrsl];
+    my ($mm, $r) = @{$self}[randmem,randrsl];
 
     for (1..4) {
         $c ^= $d << 11;                     $f += $c;       $d += $e;
@@ -336,9 +332,8 @@ package Math::Random::ISAAC::Embedded;
 
 use strict;
 use warnings;
-use Carp ();
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 use constant _backend => 0;
 
 my %CSPRNG = (
@@ -369,10 +364,10 @@ package Bytes::Random::Secure::Tiny;
 use strict;
 use warnings;
 use 5.006000;
-use Carp qw(carp croak);
+use Carp qw(croak);
 use Hash::Util;
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
 # See Math::Random::ISAAC https://rt.cpan.org/Public/Bug/Display.html?id=64324
 use constant SEED_SIZE => 256; # bits; eight 32-bit words.
@@ -420,7 +415,7 @@ sub string_from {
     my $range      = length $bag;
     croak 'Bag size must be at least one character.' unless $range;
     my $rand_bytes = q{}; # We need an empty, defined string.
-    $rand_bytes .= substr $bag, $_, 1 for $self->_ranged_randoms($range, $bytes);
+    $rand_bytes .= substr $bag, $_, 1 for @{$self->_ranged_randoms($range, $bytes)};
     return $rand_bytes;
 }
 
@@ -443,7 +438,7 @@ sub _ranged_randoms {
         $rand    = $self->irand % $divisor while $rand >= $range;
         push @randoms, $rand;
     }
-    return @randoms;
+    return \@randoms;
 }
 
 1; # POD contained in Bytes/Random/Secure/Tiny.pod
